.. _debops.tinyproxy:

debops.tinyproxy
================

The ``debops.tinyproxy`` role can be used to install Tinyproxy on a Debian or
Ubuntu host. Tinyproxy is a light-weight HTTP/HTTPS proxy daemon for POSIX operating systems.

.. toctree::
   :maxdepth: 2

   getting-started
   defaults/main
   defaults-detailed

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/debops.tinyproxy/COPYRIGHT

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:

